@@ -36,6 +36,7 @@ class LongHandler(Operation):
         self.is_comma = condition.IsComma()
         self.is_book_close = condition.IsBookClose()
         self.is_barcket_close = condition.IsBracketClose()
+        self.is_right_quota = condition.IsRightQuota()
         self.hard_max = hard_max
 
     def operate(self, state: StrSequence) -> StrSequence:
@@ -44,7 +45,7 @@ class LongHandler(Operation):
         temps_state = copy.copy(state)
         for i in range(temps_state.sentence_start, temps_state.v_pointer - 1)[::-1]:
             temps_state.v_pointer = i
-            if all([self.is_end_symbol(temps_state), self.is_book_close(temps_state)]):
+            if self.is_right_quota(temps_state) or (self.is_end_symbol(temps_state) and self.is_book_close(temps_state)):
                 cut_id = i
                 break
         else:
