@@ -66,7 +66,7 @@ class StrSequence:
 
     def sentence_list(self):
         out = []
-        for v in self.__sentence_list:
+        for v in self.sentence_list_idx:
             if v[0] < v[1]:
                 if isinstance(self.value, str):
                     out.append(self.value[v[0]:v[1]])
@@ -87,7 +87,7 @@ class StrSequence:
             print_percent(self.v_pointer, self.length, 'process cutting ')
 
     def add_to_sentence_list(self):
-        self.__sentence_list.append((self.sentence_start, min(self.length, self.v_pointer + 1)))
+        self.sentence_list_idx.append((self.sentence_start, min(self.length, self.v_pointer + 1)))
         self.sentence_start = self.v_pointer + 1
 
     def reach_right_end(self):
