@@ -1,25 +1,27 @@
 # -*- coding:utf-8 -*-
 # CREATED BY: bohuai jiang 
 # CREATED ON: 2020/8/14 4:30 PM
-# LAST MODIFIED ON:
+# LAST MODIFIED ON: 2020/10/27 7:05 PM
 # AIM:
 from typing import List
 
-from sentence_spliter.automata.state_machine import StateMachine
-from sentence_spliter.automata.sequence import StrSequence
+from .automata.state_machine import StateMachine
+from .automata.sequence import StrSequence
 
-from sentence_spliter.logic_graph import long_short_cuter, simple_cuter, special_cuter
+from .logic_graph import long_short_cuter, simple_cuter
 
 # --  init default state machine -- #
 __long_short_machine = StateMachine(long_short_cuter())
 __simple_logic = StateMachine(simple_cuter())
-__special_logic = StateMachine(special_cuter())
 
-
-def cut_to_sentences(paragraph: str, verbose: bool = False):
+def cut_to_sentences(paragraph: str, long_short: bool = False, verbose: bool = False):
     m_input = StrSequence(paragraph, verbose)
-    __special_logic.run(m_input)
-    return m_input.sentence_list()
+    if long_short:
+        __long_short_machine.run(m_input)
+        return m_input.sentence_list()
+    else:
+        __simple_logic.run(m_input)
+        return m_input.sentence_list()
 
 
 def run_cut(str_block: str, logic_graph: dict) -> List[str]:
